from .version import VERSION
import six
_TRUE_VALUES = ['y', 'Y', 'yes',  'Yes',  'YES', 'true', 'True', 'TRUE', '1', True]


class LoggingConfiguration(object):
    LOGGER_NAME = "rook"
    FILE_NAME = "rookout/python-rook.log"
    LOG_TO_STDERR = False
    LOG_LEVEL = "INFO"
    PROPAGATE_LOGS = False
    LOG_TO_REMOTE = False
    DEBUG = False


class VersionConfiguration(object):
    VERSION = VERSION
    COMMIT = "CommitGoesHere"


class ControllerAddress(object):
    HOST = 'wss://control.rookout.com'
    PORT = 443


class AgentComConfiguration(object):
    COMMAND_THREAD_NAME = "rookout_agent_com"
    MAX_MESSAGE_LENGTH = 1024 * 1024
    MAX_QUEUE_MESSAGES_LENGTH = 15 * 1024 * 1024
    BACK_OFF = 0.2
    MAX_SLEEP = 60
    TIMEOUT = 3
    REQUEST_TIMEOUT_SECS = 30
    PING_TIMEOUT = 30
    PING_INTERVAL = 10
    RESET_BACKOFF_TIMEOUT = 3*60.0
    FLUSH_TIMEOUT = 3
    MAX_QUEUED_MESSAGES = 100
    AGENT_COM_INCOMING_MAX_MESSAGE_SIZE = 500 * 1024


class OutputWsConfiguration(object):
    MAX_STATUS_UPDATES = 200
    MAX_LOG_ITEMS = 200
    MAX_AUG_MESSAGES = 100
    BUCKET_REFRESH_RATE = 10


class RateLimiter(object):
    MIN_RATE_LIMIT_VALUE_NS = 500


class InstrumentationConfig(object):
    ENGINE = "auto"
    MIN_TIME_BETWEEN_HITS_MS = 100
    MAX_AUG_TIME_MS = 400


class ImportServiceConfig(object):
    USE_IMPORT_HOOK = True
    SYS_MODULES_QUERY_INTERVAL = 0.25
    THREAD_NAME = "rookout_import_service_thread"


class HttpServerServiceConfig(object):
    SERVICES_NAMES = ""


class GitConfig(object):
    GIT_COMMIT = None
    GIT_ORIGIN = None
    SOURCES = {}


class ShutdownConfig(object):
    IS_SHUTTING_DOWN = False


class DumpConfig(object):
    STRING_CACHE_USERMESSAGE = False
    PROTOBUF_VERSION_2 = False


def update_config(new_config):
    from rook.logger import logger

    try:
        for key, val in six.iteritems(new_config):
            if key == 'PYTHON_StringCache_UserMessage':
                logger.debug("Updating StringCache_UserMessage value to: " + str(val in _TRUE_VALUES))
                DumpConfig.STRING_CACHE_USERMESSAGE = val in _TRUE_VALUES
                continue
            if key == 'PYTHON_PROTOBUF_VERSION_2':
                import os
                protobuf_2_env_var = os.environ.get('ROOKOUT_Protobuf_Version2')

                if protobuf_2_env_var:
                    logger.debug("Updating ROOKOUT_Protobuf_Version2 value to: " + str(protobuf_2_env_var in _TRUE_VALUES))
                    DumpConfig.PROTOBUF_VERSION_2 = protobuf_2_env_var in _TRUE_VALUES
                else:
                    logger.debug("Updating ROOKOUT_Protobuf_Version2 value to: " + str(val in _TRUE_VALUES))
                    DumpConfig.PROTOBUF_VERSION_2 = val in _TRUE_VALUES
                continue
    except BaseException:
        logger.exception("Failed to update configuration: " + str(new_config))



from rook.com_ws.envelope_wrappers.i_envelope_wrapper import IEnvelopeWrapper


class BasicSerializedEnvelopeWrapper(IEnvelopeWrapper):
    def __init__(self, message):
        self.buffer = IEnvelopeWrapper.get_serialized_envelope(message)

    def get_buffer(self):
        return self.buffer

    def __len__(self):
        return len(self.buffer)



import time
import websocket
import socket

from rook.com_ws import poll_select, selectable_event, selectable_queue
from rook.com_ws.agent_com_impel.agent_com_base import AgentComBase, FlushMessagesEvent
from rook.config import AgentComConfiguration

from rook.logger import logger
import rook.protobuf.envelope_pb2 as envelope_pb
from six.moves.queue import Empty


class SingleThreadAgentCom(AgentComBase):

    def __init__(self, agent_id, host, port, proxy, token, labels, tags, debug, print_on_initial_connection):
        super(SingleThreadAgentCom, self).__init__(agent_id, host, port, proxy, token, labels, tags, debug,
                                                   print_on_initial_connection)

        # Queue hold outgoing messages wrapped with IEnvelopeWrapper
        self._queue = selectable_queue.SelectableQueue()

    def await_message(self, message_name):
        event = selectable_event.SelectableEvent()
        self.once(message_name, lambda _: event.set())

        return event

    def _create_run_connection_thread(self):
        with self.await_message('InitialAugsCommand') as got_initial_augs_event:
            try:
                self.run_until_stopped(got_initial_augs_event)
            except Exception as exc:
                logger.exception("network loop stopped: %s", exc)

    def run_until_stopped(self, got_initial_augs_event):
        self._connection.ping()
        waiter = poll_select.Waiter([self._connection, self._queue, got_initial_augs_event], [], [self._connection])
        last_ping_time = 0
        last_read_time = time.time()
        got_initial_augs_started_waiting = time.time()
        got_initial_augs_keep_waiting = True
        while self._running:
            # this is similar to the select API: rlist, wlist, xlist - fds ready to read, ready to write, and errors
            # see official documentation for POSIX select or Python select.select for further info
            rlist, _, xlist = waiter.wait(AgentComConfiguration.PING_INTERVAL)

            # if it's time to send a ping, go ahead and do it now
            if (time.time() - last_ping_time) >= AgentComConfiguration.PING_INTERVAL:
                last_ping_time = time.time()
                logger.debug("Sending ping")
                self._connection.ping()
            # if rlist and xlist are empty -> the wait timed out, so check if we had a ping timeout
            if len(rlist) == 0 and len(xlist) == 0 and (
                    time.time() - last_read_time) >= AgentComConfiguration.PING_TIMEOUT:
                logger.debug("Disconnecting due to ping timeout")
                self._connection.close()
                break

            # got initial augs is ready, so don't wait on it anymore
            if got_initial_augs_event in rlist:
                # don't wait on got_initial_augs_event anymore
                got_initial_augs_keep_waiting = False
                waiter = poll_select.Waiter([self._connection, self._queue], [], [self._connection])
                logger.info("Finished initialization")
            # still waiting for got initial augs, but reached timeout, don't wait on it anymore
            if got_initial_augs_keep_waiting and (
                    time.time() - got_initial_augs_started_waiting) >= AgentComConfiguration.TIMEOUT:
                got_initial_augs_keep_waiting = False
                waiter = poll_select.Waiter([self._connection, self._queue], [], [self._connection])
                logger.warning("Timeout waiting for initial augs")
            # connection appeared in xlist, means it was closed
            if self._connection in xlist:
                logger.info("Connection closed")
                break
            # connection appeared in rlist, means there's data to read
            if self._connection in rlist:
                last_read_time = time.time()
                try:
                    code, msg = self._connection.recv_data(control_frame=True)
                    if code == websocket.ABNF.OPCODE_BINARY:
                        if msg is None:
                            # socket disconnected
                            logger.debug("Reading msg - socket disconnected")
                            break

                        if len(msg) > AgentComConfiguration.AGENT_COM_INCOMING_MAX_MESSAGE_SIZE:
                            logger.error("message length (%d) exceed max size", msg)
                            continue

                        envelope = envelope_pb.Envelope()
                        envelope.ParseFromString(msg)
                        self._handle_incoming_message(envelope)
                except (socket.error, websocket.WebSocketConnectionClosedException):
                    logger.debug("Reading msg - socket disconnected")
                    break
            # queue appeared in rlist, means there's a new message to send
            if self._queue in rlist:
                wrapped_envelope = None
                try:
                    wrapped_envelope = self._queue.get()
                    msg = wrapped_envelope.get_buffer()
                    if isinstance(msg, FlushMessagesEvent):
                        msg.event.set()
                        continue
                    self._connection.send_binary(msg)
                except (socket.error, websocket.WebSocketConnectionClosedException):
                    if wrapped_envelope is not None:
                        self._queue.put(wrapped_envelope)
                    logger.info("Got websocket closed exception")
                    break
                except Empty:
                    continue
                self._queue_messages_length - len(wrapped_envelope)

        logger.warning("loop stopped running")




import threading


class UserWarnings(object):

    _tls = threading.local()

    def __init__(self, reporter):
        self._reporter = reporter
        self._old_value = None

    def __enter__(self):
        self._old_value = self.set_reporter(self._reporter)

    def __exit__(self, exc_type, exc_val, exc_tb):
        self.set_reporter(self._old_value)

    @classmethod
    def set_reporter(cls, warning_reporter):
        old_value = getattr(cls._tls, "warning_reporter", None)
        cls._tls.warning_reporter = warning_reporter
        return old_value

    @classmethod
    def send_warning(cls, error):
        if hasattr(cls._tls, "warning_reporter") and cls._tls.warning_reporter:
            cls._tls.warning_reporter.send_warning(error)

    @classmethod
    def set_error(cls, error):
        if hasattr(cls._tls, "warning_reporter") and cls._tls.warning_reporter:
            cls._tls.warning_reporter.set_error(error)



class ActionRunProcessor(object):
    NAME = 'script'

    def __init__(self, configuration, processor_factory):
        self.processor = processor_factory.get_processor(configuration['operations'])

    def execute(self, aug_id, report_id, namespace, output):
        self.processor.process(namespace)
        output.send_user_message(aug_id, report_id, namespace['store'])



"""This service will execute sub-services according to the HttpServerServiceConfig.SERVICES_NAMES
    Services names separated by semicolon - the augs are global to all of those services"""

from threading import RLock
import six
import os

from rook.config import HttpServerServiceConfig
from .flask_tracer import FlaskTracer

from rook.exceptions import RookNoHttpServiceRegistered


class HttpServerService(object):
    NAME = "HttpService"

    def __init__(self):
        self._lock = RLock()
        self._augs = {}
        self._services = {}

        services_names = os.environ.get('ROOKOUT_HTTP_SERVICES', HttpServerServiceConfig.SERVICES_NAMES).split(';')

        if FlaskTracer.NAME in services_names:
            self._services[FlaskTracer.NAME] = FlaskTracer(self.execute_augs)

    def add_logging_aug(self, aug):
        with self._lock:
            if len(self._services) == 0:
                raise RookNoHttpServiceRegistered()

            self._augs[aug.aug_id] = aug
            aug.set_active()

    def remove_aug(self, aug_id):
        with self._lock:
            try:
                aug = self._augs[aug_id]
            except KeyError:
                return

            del self._augs[aug_id]
            aug.set_removed()

    def clear_augs(self):
        with self._lock:
            aug_ids = list(self._augs.keys())

            for aug_id in aug_ids:
                self.remove_aug(aug_id)

    def close(self):
        self.clear_augs()

    def execute_augs(self, extracted):
        with self._lock:
            for aug in six.itervalues(self._augs):
                aug.execute(dict(), extracted)

    def pre_fork(self):
        if self._lock:
            self._lock.acquire()

    def post_fork(self):
        if self._lock:
            self._lock.release()



"""This is the external interface to the Rook package."""
import sys
import os
import traceback
import re

import six

from rook.config import ImportServiceConfig
from rook.serverless import on_lambda
from rook.fork_utils import detect_multiprocessing

_rook = None
_debug = False
_throw_errors = False

_fork = None
_original_args = None

_TRUE_VALUES = ['y', 'Y', 'yes',  'Yes',  'YES', 'true', 'True', 'TRUE', '1', True]


def start(token=None,
          tags=None,
          host=None,
          port=None,
          debug=None,
          throw_errors=None,
          log_file=None,
          log_level=None,
          log_to_stderr=None,
          labels=None,
          use_import_hook=None,
          git_commit=None,
          git_origin=None,
          proxy=None,
          fork=None,
          enable_monitor=None,
          sources=None,
          **kwargs):
    global _rook, _debug, _throw_errors, _original_args, _fork

    for k, v in os.environ.items():
        if k.startswith("ROOKOUT_") and "LABELS" not in k:
            os.environ[k] = v.strip().strip("'\"")  # First strip for whitespaces, then ' and "

    if _rook is not None:
        return

    if _original_args:
        copy_of_original_args = _original_args
        _original_args = None

        # Disable fork support on child processes
        copy_of_original_args['fork'] = False

        start(**copy_of_original_args)
        return

    # Save original args to recover from fork
    _original_args = locals()

    if isinstance(debug, bool):
        _debug = debug
    else:
        _debug = os.environ.get('ROOKOUT_DEBUG') in _TRUE_VALUES

    if not isinstance(log_to_stderr, bool):
        log_to_stderr = os.environ.get('ROOKOUT_LOG_TO_STDERR') in _TRUE_VALUES

    if isinstance(throw_errors, bool):
        _throw_errors = throw_errors

    if not isinstance(tags, list) and isinstance(os.environ.get('ROOKOUT_ROOK_TAGS'), six.string_types):
        raw_tags = os.environ.get('ROOKOUT_ROOK_TAGS')
        tags = [_normalize_string(tag.strip(' \'"')) for tag in raw_tags.split(';') if tag]

    if not isinstance(labels, dict) and isinstance(os.environ.get('ROOKOUT_LABELS'), six.string_types):
        raw_labels = os.environ.get('ROOKOUT_LABELS')
        labels = {}
        for label in raw_labels.split(','):
            label = _normalize_string(label.strip(' \'"'))
            keyvalue = label.split(':')
            if len(keyvalue) == 2:
                key,value = keyvalue
                if key and value:
                    _validate_label(key)
                    labels[key] = value

    if on_lambda():
        log_file = ""
    log_file = log_file or os.environ.get('ROOKOUT_LOG_FILE')
    log_level = log_level or os.environ.get('ROOKOUT_LOG_LEVEL')

    from rook.config import ControllerAddress
    host_specified = host or os.environ.get('ROOKOUT_CONTROLLER_HOST') or os.environ.get('ROOKOUT_AGENT_HOST')
    host = host_specified or ControllerAddress.HOST
    port = port or os.environ.get('ROOKOUT_CONTROLLER_PORT') or os.environ.get('ROOKOUT_AGENT_PORT') or ControllerAddress.PORT
    proxy = proxy or os.environ.get('ROOKOUT_PROXY')
    token = token or os.environ.get('ROOKOUT_TOKEN')
    use_import_hook = use_import_hook if use_import_hook is not None else os.environ.get('ROOKOUT_USE_IMPORT_HOOK',
                                                                                         True) in _TRUE_VALUES
    async_start = os.environ.get('ROOKOUT_ASYNC_START', False) in _TRUE_VALUES

    if fork is None and 'ROOKOUT_ENABLE_FORK' not in os.environ:
        _fork = detect_multiprocessing()
    else:
        _fork = fork or os.environ.get('ROOKOUT_ENABLE_FORK', False) in _TRUE_VALUES

    _enable_monitor = enable_monitor or os.environ.get('ROOKOUT_ENABLE_MONITOR', True) in _TRUE_VALUES

    try:
        token = token.strip().strip("'\"")
        proxy = proxy.strip().strip("'\"")
        host_specified = host_specified.strip().strip("'\"")
    except AttributeError:
        pass

    try:
        from rook.exceptions import RookMissingToken, RookInvalidToken, RookVersionNotSupported, \
            RookCommunicationException, RookInvalidOptions, RookLoadError, RookOldServers, \
            RookInvalidRateLimitConfiguration
        try:
            from rook.config import LoggingConfiguration, GitConfig

            if git_commit is not None:
                if not isinstance(git_commit, six.string_types):
                    raise RookInvalidOptions('git_commit should be a String')
                GitConfig.GIT_COMMIT = git_commit

            if git_origin is not None:
                if not isinstance(git_origin, six.string_types):
                    raise RookInvalidOptions('git_origin should be a String')
                GitConfig.GIT_ORIGIN = git_origin

            if sources is not None and not isinstance(sources, dict):
                raise RookInvalidOptions('sources should be a dict')
                
            if not isinstance(sources, dict) and isinstance(os.environ.get('ROOKOUT_SOURCES'), six.string_types):
                raw_sources = os.environ.get('ROOKOUT_SOURCES')
                sources = {}
                for source in raw_sources.split(';'):
                    source = _normalize_string(source.strip(' \'"'))
                    keyvalue = source.split('#')
                    if len(keyvalue) == 2:
                        key,value = keyvalue
                        if key and value:                    
                            sources[key] = value
            if sources:                             
                GitConfig.SOURCES = sources

            if log_file is not None:
                if not isinstance(log_file, six.string_types):
                    raise RookInvalidOptions('log_file should be a String')
                LoggingConfiguration.FILE_NAME = log_file

            if log_level is not None:
                if not isinstance(log_level, six.string_types):
                    raise RookInvalidOptions('log_level should be a String')
                LoggingConfiguration.LOG_LEVEL = log_level

            if log_to_stderr is not None:
                LoggingConfiguration.LOG_TO_STDERR = log_to_stderr

            if proxy is not None and not isinstance(proxy, six.string_types):
                raise RookInvalidOptions('proxy should be a String')

            if _debug:
                LoggingConfiguration.LOG_LEVEL = 'DEBUG'
                LoggingConfiguration.LOG_TO_STDERR = True
                LoggingConfiguration.DEBUG = True

            if use_import_hook is not None:
                ImportServiceConfig.USE_IMPORT_HOOK = use_import_hook

            if isinstance(tags, list):
                for tag in tags:
                    if not isinstance(tag, six.string_types):
                        raise RookInvalidOptions('Rook tags should be array of strings')
            else:
                if tags:
                    raise RookInvalidOptions('Rook tags should be array of strings')

            if not host_specified and not token:
                raise RookMissingToken()
            else:
                if token is not None:
                    _validate_token(token)

            if _debug:
                _print_user_configuration(token=token[:5] + "....." if token else None, host=host, port=port,
                                          proxy=proxy, throw_errors=throw_errors, log_level=log_level,
                                          log_to_stderr=log_to_stderr, log_file=log_file, git_commit=git_commit,
                                          git_origin=git_origin, tags=tags, labels=labels, async_start=async_start,
                                          use_import_hook=use_import_hook, fork=_fork, enable_monitor=_enable_monitor, sources=sources)

            if (host == "staging.cloud.agent.rookout.com") or (host == "cloud.agent.rookout.com"):
                raise RookOldServers()

            from rook.logger import logger
            from rook.config import VersionConfiguration
            logger.debug("Rookout SDK for Python, Version:" + VersionConfiguration.VERSION + " Commit:" + VersionConfiguration.COMMIT)

            import rook.singleton
            _rook = rook.singleton.singleton_obj

            _rook.connect(token, host, port, proxy, tags, labels, async_start, _fork, _debug, _enable_monitor, _throw_errors)
        except (RookMissingToken, RookInvalidToken, RookVersionNotSupported, RookOldServers,
                RookInvalidRateLimitConfiguration) as e:
            if not _throw_errors:
                six.print_("[Rookout] Failed to start Rookout:", e, file=sys.stderr)
            raise
        except RookCommunicationException as e:
            if not _throw_errors:
                logger.warn("[Rookout] Failed to connect to the controller - will continue attempting in the background", e, file=sys.stderr)
            raise
        except ImportError as e:
            if not _throw_errors:
                six.print_("[Rookout] Failed to import dependencies:", e, file=sys.stderr)
            raise
        except (Exception, RookLoadError) as e:
            if not _throw_errors:
                six.print_("[Rookout] Failed initialization:", e, file=sys.stderr)
            raise
    except Exception:
        if _throw_errors:
            raise

        if _debug:
            traceback.print_exc()


def capture_exception(exc):
    from rook.collect import exception_collect

    exception_collect(exc)


def flush():
    global _rook
    if _rook is None:
        return

    _rook.flush()


def stop():
    global _rook
    if _rook is None:
        return

    _rook.stop()
    _rook = None


def restart(labels=None,
            tags=None):
    global _rook
    if _rook is None:
        return

    _rook.restart(tags, labels)


def _normalize_string(obj):
    if six.PY2:
        if isinstance(obj, str):
            return unicode(obj, errors="replace")
        else:
            return unicode(obj)
    else:
        return str(obj)


def _validate_token(token):
    from rook.exceptions import RookInvalidOptions

    if not isinstance(token, six.string_types):
        raise RookInvalidOptions('Rookout token should be a String')

    if len(token) != 64:
        raise RookInvalidOptions('Rookout token should be 64 characters')

    if re.match("^[0-9a-zA-Z]{0,64}$", token) is None:
        raise RookInvalidOptions('Rookout token must consist of only hexadecimal characters')


def _validate_label(label):
    from rook.exceptions import RookInvalidLabel

    if label.startswith("$"):
        raise RookInvalidLabel(label)


def _print_user_configuration(**kwargs):
    try:
        config_string = ""
        for key, value in kwargs.items():
            if value:
                config_string = config_string + ("%s: %s, " % (key, value))
        six.print_("RookOptions: " + config_string)
    except Exception:
        six.print_("Error in printing user configuration")



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: messages.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import variant_pb2 as variant__pb2
from . import variant2_pb2 as variant2__pb2
from . import agent_info_pb2 as agent__info__pb2
from . import controller_info_pb2 as controller__info__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='messages.proto',
  package='com.rookout',
  syntax='proto3',
  serialized_options=b'\n\031com.rookout.rook.protobufZ2github.com/Rookout/management/pkg/protos/protobuf2',
  serialized_pb=b'\n\x0emessages.proto\x12\x0b\x63om.rookout\x1a\rvariant.proto\x1a\x0evariant2.proto\x1a\x10\x61gent_info.proto\x1a\x15\x63ontroller_info.proto\x1a\x19google/protobuf/any.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"D\n\x0fNewAgentMessage\x12\x31\n\nagent_info\x18\x01 \x01(\x0b\x32\x1d.com.rookout.AgentInformation\">\n\nStackFrame\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\x12\x0c\n\x04line\x18\x02 \x01(\r\x12\x10\n\x08\x66unction\x18\x03 \x01(\t\"5\n\nStackTrace\x12\'\n\x06\x66rames\x18\x01 \x03(\x0b\x32\x17.com.rookout.StackFrame\"~\n\tException\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t\x12&\n\x08instance\x18\x03 \x01(\x0b\x32\x14.com.rookout.Variant\x12*\n\ttraceback\x18\x04 \x01(\x0b\x32\x17.com.rookout.StackTrace\"\xe2\x03\n\nLogMessage\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x10\n\x08\x61gent_id\x18\x02 \x01(\t\x12/\n\x05level\x18\x03 \x01(\x0e\x32 .com.rookout.LogMessage.LogLevel\x12\x10\n\x08\x66ilename\x18\x04 \x01(\t\x12\x0c\n\x04line\x18\x05 \x01(\r\x12\x0c\n\x04text\x18\x06 \x01(\t\x12\'\n\targuments\x18\x07 \x03(\x0b\x32\x14.com.rookout.Variant\x12)\n\texception\x18\x08 \x01(\x0b\x32\x16.com.rookout.Exception\x12\x1d\n\x11\x66ormatted_message\x18\t \x01(\tB\x02\x18\x01\x12\x32\n\x10legacy_arguments\x18\n \x01(\x0b\x32\x14.com.rookout.VariantB\x02\x18\x01\x12\x12\n\nclass_name\x18\x0b \x01(\t\x12\x13\n\x0bmethod_name\x18\x0c \x01(\t\x12\x15\n\rcontroller_id\x18\r \x01(\t\"M\n\x08LogLevel\x12\t\n\x05TRACE\x10\x00\x12\t\n\x05\x44\x45\x42UG\x10\x01\x12\x08\n\x04INFO\x10\x02\x12\x0b\n\x07WARNING\x10\x03\x12\t\n\x05\x45RROR\x10\x04\x12\t\n\x05\x46\x41TAL\x10\x05\"\xa3\x05\n\x14\x43ontrollerLogMessage\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x39\n\x05level\x18\x02 \x01(\x0e\x32*.com.rookout.ControllerLogMessage.LogLevel\x12\x10\n\x08\x66ilename\x18\x03 \x01(\t\x12\x0c\n\x04line\x18\x04 \x01(\r\x12\x0c\n\x04text\x18\x05 \x01(\t\x12\x12\n\nclass_name\x18\x06 \x01(\t\x12\x13\n\x0bmethod_name\x18\x07 \x01(\t\x12\x15\n\rcontroller_id\x18\x08 \x01(\t\x12\x36\n\x05\x65rror\x18\t \x01(\x0b\x32\'.com.rookout.ControllerLogMessage.Error\x12\x41\n\x08metadata\x18\n \x03(\x0b\x32/.com.rookout.ControllerLogMessage.MetadataEntry\x12U\n\x12metadataJSONValues\x18\x0b \x03(\x0b\x32\x39.com.rookout.ControllerLogMessage.MetadataJSONValuesEntry\x1a&\n\x05\x45rror\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x39\n\x17MetadataJSONValuesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"M\n\x08LogLevel\x12\t\n\x05TRACE\x10\x00\x12\t\n\x05\x44\x45\x42UG\x10\x01\x12\x08\n\x04INFO\x10\x02\x12\x0b\n\x07WARNING\x10\x03\x12\t\n\x05\x45RROR\x10\x04\x12\t\n\x05\x46\x41TAL\x10\x05\"\x80\x01\n\x11RuleStatusMessage\x12\x10\n\x08\x61gent_id\x18\x01 \x01(\t\x12\x0f\n\x07rule_id\x18\x02 \x01(\t\x12\x0e\n\x06\x61\x63tive\x18\x03 \x01(\t\x12!\n\x05\x65rror\x18\x04 \x01(\x0b\x32\x12.com.rookout.Error\x12\x15\n\rcontroller_id\x18\x05 \x01(\t\"\xf0\x02\n\x10\x41ugReportMessage\x12\x10\n\x08\x61gent_id\x18\x01 \x01(\t\x12\x0e\n\x06\x61ug_id\x18\x02 \x01(\t\x12\'\n\targuments\x18\x03 \x01(\x0b\x32\x14.com.rookout.Variant\x12\x11\n\treport_id\x18\x04 \x01(\t\x12\x46\n\rstrings_cache\x18\x05 \x03(\x0b\x32/.com.rookout.AugReportMessage.StringsCacheEntry\x12\x1c\n\x14\x62uffer_cache_buffers\x18\x06 \x03(\x0c\x12\x1c\n\x14\x62uffer_cache_indexes\x18\x07 \x03(\r\x12)\n\narguments2\x18\x08 \x01(\x0b\x32\x15.com.rookout.Variant2\x12\x1a\n\x12reverse_list_order\x18\t \x01(\x08\x1a\x33\n\x11StringsCacheEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\r:\x02\x38\x01\"e\n\x07UserMsg\x12\x31\n\naug_report\x18\x01 \x01(\x0b\x32\x1d.com.rookout.AugReportMessage\x12\x11\n\treport_id\x18\x02 \x01(\t\x12\x14\n\x0cworkspace_id\x18\x03 \x01(\t\"!\n\rAddAugCommand\x12\x10\n\x08\x61ug_json\x18\x01 \x01(\t\"\xad\x01\n\x12InitialAugsCommand\x12\x0c\n\x04\x61ugs\x18\x01 \x03(\t\x12P\n\x11sdk_configuration\x18\x02 \x03(\x0b\x32\x35.com.rookout.InitialAugsCommand.SdkConfigurationEntry\x1a\x37\n\x15SdkConfigurationEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\"\n\x10RemoveAugCommand\x12\x0e\n\x06\x61ug_id\x18\x01 \x01(\t\"\x15\n\x13InitFinishedMessage\"\x12\n\x10\x43learAugsCommand\"\x1c\n\x0bPingMessage\x12\r\n\x05value\x18\x01 \x01(\x05\"\x1f\n\x0c\x45rrorMessage\x12\x0f\n\x07message\x18\x01 \x01(\t\"e\n\x0e\x43\x32\x43InitMessage\x12:\n\x0e\x63ontrollerInfo\x18\x01 \x01(\x0b\x32\".com.rookout.ControllerInformation\x12\x17\n\x0f\x63onnectedAgents\x18\x02 \x03(\t\"U\n\x16\x44\x61taOnPremTokenRequest\x12;\n\x0b\x61\x63\x63\x65ss_type\x18\x01 \x01(\x0e\x32&.com.rookout.DataOnPremTokenAccessType\"(\n\x17\x44\x61taOnPremTokenResponse\x12\r\n\x05token\x18\x01 \x01(\x0c\" \n\nAgentsList\x12\x12\n\nagents_ids\x18\x01 \x03(\t\"!\n\x0c\x41ssertAgents\x12\x11\n\tagent_ids\x18\x01 \x03(\t\"-\n\x17InvalidateAgentsCommand\x12\x12\n\nagents_ids\x18\x01 \x03(\t\"*\n\x14\x43onfirmAgentsCommand\x12\x12\n\nagents_ids\x18\x01 \x03(\t\":\n\x13\x41gentIdHitCountPair\x12\x10\n\x08\x61gent_id\x18\x01 \x01(\t\x12\x11\n\thit_count\x18\x02 \x01(\r\"f\n\x15HitCountUpdateMessage\x12\x0e\n\x06\x61ug_id\x18\x01 \x01(\t\x12=\n\x13hitCountInformation\x18\x02 \x03(\x0b\x32 .com.rookout.AgentIdHitCountPair\"L\n\rC2cRpcRequest\x12\x14\n\x0crequest_uuid\x18\x01 \x01(\t\x12%\n\x07message\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\"\\\n\x0e\x43\x32\x63RpcResponse\x12\x14\n\x0crequest_uuid\x18\x01 \x01(\t\x12%\n\x07message\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\x12\r\n\x05\x65rror\x18\x03 \x01(\t\"w\n%StartDatastoreConnectivityTestCommand\x12\r\n\x05orgId\x18\x01 \x01(\t\x12\x14\n\x0c\x63ontrollerId\x18\x02 \x01(\t\x12\x14\n\x0c\x64\x61tastoreUrl\x18\x03 \x01(\t\x12\x13\n\x0bworkspaceId\x18\x04 \x01(\t\"{\n$DatastoreConnectivityTestC2cResponse\x12\x14\n\x0c\x63ontrollerId\x18\x01 \x01(\t\x12\x15\n\rTestMessageId\x18\x02 \x01(\t\x12\x11\n\tisSuccess\x18\x03 \x01(\x08\x12\x13\n\x0b\x65rrorString\x18\x04 \x01(\t\",\n\x14PingDatastoreCommand\x12\x14\n\x0c\x64\x61tastoreUrl\x18\x01 \x01(\t\"\xb3\x01\n\x14\x44\x61tastoreInformation\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x10\n\x08hostname\x18\x02 \x01(\t\x12\x14\n\x0cmachine_type\x18\x03 \x01(\t\x12\x0f\n\x07network\x18\x04 \x01(\t\x12\n\n\x02ip\x18\x05 \x01(\t\x12\n\n\x02os\x18\x06 \x01(\t\x12\x12\n\nos_release\x18\x07 \x01(\t\x12\x12\n\nos_version\x18\x08 \x01(\t\x12\x11\n\tos_string\x18\t \x01(\t*0\n\x19\x44\x61taOnPremTokenAccessType\x12\t\n\x05WRITE\x10\x00\x12\x08\n\x04READ\x10\x01\x42O\n\x19\x63om.rookout.rook.protobufZ2github.com/Rookout/management/pkg/protos/protobuf2b\x06proto3'
  ,
  dependencies=[variant__pb2.DESCRIPTOR,variant2__pb2.DESCRIPTOR,agent__info__pb2.DESCRIPTOR,controller__info__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])

_DATAONPREMTOKENACCESSTYPE = _descriptor.EnumDescriptor(
  name='DataOnPremTokenAccessType',
  full_name='com.rookout.DataOnPremTokenAccessType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='WRITE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='READ', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3803,
  serialized_end=3851,
)
_sym_db.RegisterEnumDescriptor(_DATAONPREMTOKENACCESSTYPE)

DataOnPremTokenAccessType = enum_type_wrapper.EnumTypeWrapper(_DATAONPREMTOKENACCESSTYPE)
WRITE = 0
READ = 1


_LOGMESSAGE_LOGLEVEL = _descriptor.EnumDescriptor(
  name='LogLevel',
  full_name='com.rookout.LogMessage.LogLevel',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TRACE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEBUG', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INFO', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WARNING', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FATAL', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=886,
  serialized_end=963,
)
_sym_db.RegisterEnumDescriptor(_LOGMESSAGE_LOGLEVEL)

_CONTROLLERLOGMESSAGE_LOGLEVEL = _descriptor.EnumDescriptor(
  name='LogLevel',
  full_name='com.rookout.ControllerLogMessage.LogLevel',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TRACE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEBUG', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INFO', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WARNING', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FATAL', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=886,
  serialized_end=963,
)
_sym_db.RegisterEnumDescriptor(_CONTROLLERLOGMESSAGE_LOGLEVEL)


_NEWAGENTMESSAGE = _descriptor.Descriptor(
  name='NewAgentMessage',
  full_name='com.rookout.NewAgentMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='agent_info', full_name='com.rookout.NewAgentMessage.agent_info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=163,
  serialized_end=231,
)


_STACKFRAME = _descriptor.Descriptor(
  name='StackFrame',
  full_name='com.rookout.StackFrame',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='filename', full_name='com.rookout.StackFrame.filename', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line', full_name='com.rookout.StackFrame.line', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='function', full_name='com.rookout.StackFrame.function', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=233,
  serialized_end=295,
)


_STACKTRACE = _descriptor.Descriptor(
  name='StackTrace',
  full_name='com.rookout.StackTrace',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='frames', full_name='com.rookout.StackTrace.frames', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=297,
  serialized_end=350,
)


_EXCEPTION = _descriptor.Descriptor(
  name='Exception',
  full_name='com.rookout.Exception',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='com.rookout.Exception.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='com.rookout.Exception.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instance', full_name='com.rookout.Exception.instance', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='traceback', full_name='com.rookout.Exception.traceback', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=352,
  serialized_end=478,
)


_LOGMESSAGE = _descriptor.Descriptor(
  name='LogMessage',
  full_name='com.rookout.LogMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='com.rookout.LogMessage.timestamp', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='agent_id', full_name='com.rookout.LogMessage.agent_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='level', full_name='com.rookout.LogMessage.level', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filename', full_name='com.rookout.LogMessage.filename', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line', full_name='com.rookout.LogMessage.line', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='text', full_name='com.rookout.LogMessage.text', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='arguments', full_name='com.rookout.LogMessage.arguments', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exception', full_name='com.rookout.LogMessage.exception', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='formatted_message', full_name='com.rookout.LogMessage.formatted_message', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='legacy_arguments', full_name='com.rookout.LogMessage.legacy_arguments', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='class_name', full_name='com.rookout.LogMessage.class_name', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='method_name', full_name='com.rookout.LogMessage.method_name', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='controller_id', full_name='com.rookout.LogMessage.controller_id', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _LOGMESSAGE_LOGLEVEL,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=481,
  serialized_end=963,
)


_CONTROLLERLOGMESSAGE_ERROR = _descriptor.Descriptor(
  name='Error',
  full_name='com.rookout.ControllerLogMessage.Error',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='com.rookout.ControllerLogMessage.Error.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='com.rookout.ControllerLogMessage.Error.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1416,
  serialized_end=1454,
)

_CONTROLLERLOGMESSAGE_METADATAENTRY = _descriptor.Descriptor(
  name='MetadataEntry',
  full_name='com.rookout.ControllerLogMessage.MetadataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='com.rookout.ControllerLogMessage.MetadataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.rookout.ControllerLogMessage.MetadataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1456,
  serialized_end=1503,
)

_CONTROLLERLOGMESSAGE_METADATAJSONVALUESENTRY = _descriptor.Descriptor(
  name='MetadataJSONValuesEntry',
  full_name='com.rookout.ControllerLogMessage.MetadataJSONValuesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='com.rookout.ControllerLogMessage.MetadataJSONValuesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.rookout.ControllerLogMessage.MetadataJSONValuesEntry.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1505,
  serialized_end=1562,
)

_CONTROLLERLOGMESSAGE = _descriptor.Descriptor(
  name='ControllerLogMessage',
  full_name='com.rookout.ControllerLogMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='com.rookout.ControllerLogMessage.timestamp', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='level', full_name='com.rookout.ControllerLogMessage.level', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filename', full_name='com.rookout.ControllerLogMessage.filename', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line', full_name='com.rookout.ControllerLogMessage.line', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='text', full_name='com.rookout.ControllerLogMessage.text', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='class_name', full_name='com.rookout.ControllerLogMessage.class_name', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='method_name', full_name='com.rookout.ControllerLogMessage.method_name', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='controller_id', full_name='com.rookout.ControllerLogMessage.controller_id', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='com.rookout.ControllerLogMessage.error', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='com.rookout.ControllerLogMessage.metadata', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadataJSONValues', full_name='com.rookout.ControllerLogMessage.metadataJSONValues', index=10,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CONTROLLERLOGMESSAGE_ERROR, _CONTROLLERLOGMESSAGE_METADATAENTRY, _CONTROLLERLOGMESSAGE_METADATAJSONVALUESENTRY, ],
  enum_types=[
    _CONTROLLERLOGMESSAGE_LOGLEVEL,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=966,
  serialized_end=1641,
)


_RULESTATUSMESSAGE = _descriptor.Descriptor(
  name='RuleStatusMessage',
  full_name='com.rookout.RuleStatusMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='agent_id', full_name='com.rookout.RuleStatusMessage.agent_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rule_id', full_name='com.rookout.RuleStatusMessage.rule_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='active', full_name='com.rookout.RuleStatusMessage.active', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='com.rookout.RuleStatusMessage.error', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='controller_id', full_name='com.rookout.RuleStatusMessage.controller_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1644,
  serialized_end=1772,
)


_AUGREPORTMESSAGE_STRINGSCACHEENTRY = _descriptor.Descriptor(
  name='StringsCacheEntry',
  full_name='com.rookout.AugReportMessage.StringsCacheEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='com.rookout.AugReportMessage.StringsCacheEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.rookout.AugReportMessage.StringsCacheEntry.value', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2092,
  serialized_end=2143,
)

_AUGREPORTMESSAGE = _descriptor.Descriptor(
  name='AugReportMessage',
  full_name='com.rookout.AugReportMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='agent_id', full_name='com.rookout.AugReportMessage.agent_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='aug_id', full_name='com.rookout.AugReportMessage.aug_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='arguments', full_name='com.rookout.AugReportMessage.arguments', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='report_id', full_name='com.rookout.AugReportMessage.report_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='strings_cache', full_name='com.rookout.AugReportMessage.strings_cache', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='buffer_cache_buffers', full_name='com.rookout.AugReportMessage.buffer_cache_buffers', index=5,
      number=6, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='buffer_cache_indexes', full_name='com.rookout.AugReportMessage.buffer_cache_indexes', index=6,
      number=7, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='arguments2', full_name='com.rookout.AugReportMessage.arguments2', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reverse_list_order', full_name='com.rookout.AugReportMessage.reverse_list_order', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_AUGREPORTMESSAGE_STRINGSCACHEENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1775,
  serialized_end=2143,
)


_USERMSG = _descriptor.Descriptor(
  name='UserMsg',
  full_name='com.rookout.UserMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='aug_report', full_name='com.rookout.UserMsg.aug_report', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='report_id', full_name='com.rookout.UserMsg.report_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='workspace_id', full_name='com.rookout.UserMsg.workspace_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2145,
  serialized_end=2246,
)


_ADDAUGCOMMAND = _descriptor.Descriptor(
  name='AddAugCommand',
  full_name='com.rookout.AddAugCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='aug_json', full_name='com.rookout.AddAugCommand.aug_json', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2248,
  serialized_end=2281,
)


_INITIALAUGSCOMMAND_SDKCONFIGURATIONENTRY = _descriptor.Descriptor(
  name='SdkConfigurationEntry',
  full_name='com.rookout.InitialAugsCommand.SdkConfigurationEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='com.rookout.InitialAugsCommand.SdkConfigurationEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.rookout.InitialAugsCommand.SdkConfigurationEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2402,
  serialized_end=2457,
)

_INITIALAUGSCOMMAND = _descriptor.Descriptor(
  name='InitialAugsCommand',
  full_name='com.rookout.InitialAugsCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='augs', full_name='com.rookout.InitialAugsCommand.augs', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sdk_configuration', full_name='com.rookout.InitialAugsCommand.sdk_configuration', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_INITIALAUGSCOMMAND_SDKCONFIGURATIONENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2284,
  serialized_end=2457,
)


_REMOVEAUGCOMMAND = _descriptor.Descriptor(
  name='RemoveAugCommand',
  full_name='com.rookout.RemoveAugCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='aug_id', full_name='com.rookout.RemoveAugCommand.aug_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2459,
  serialized_end=2493,
)


_INITFINISHEDMESSAGE = _descriptor.Descriptor(
  name='InitFinishedMessage',
  full_name='com.rookout.InitFinishedMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2495,
  serialized_end=2516,
)


_CLEARAUGSCOMMAND = _descriptor.Descriptor(
  name='ClearAugsCommand',
  full_name='com.rookout.ClearAugsCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2518,
  serialized_end=2536,
)


_PINGMESSAGE = _descriptor.Descriptor(
  name='PingMessage',
  full_name='com.rookout.PingMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='com.rookout.PingMessage.value', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2538,
  serialized_end=2566,
)


_ERRORMESSAGE = _descriptor.Descriptor(
  name='ErrorMessage',
  full_name='com.rookout.ErrorMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='com.rookout.ErrorMessage.message', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2568,
  serialized_end=2599,
)


_C2CINITMESSAGE = _descriptor.Descriptor(
  name='C2CInitMessage',
  full_name='com.rookout.C2CInitMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='controllerInfo', full_name='com.rookout.C2CInitMessage.controllerInfo', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='connectedAgents', full_name='com.rookout.C2CInitMessage.connectedAgents', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2601,
  serialized_end=2702,
)


_DATAONPREMTOKENREQUEST = _descriptor.Descriptor(
  name='DataOnPremTokenRequest',
  full_name='com.rookout.DataOnPremTokenRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='access_type', full_name='com.rookout.DataOnPremTokenRequest.access_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2704,
  serialized_end=2789,
)


_DATAONPREMTOKENRESPONSE = _descriptor.Descriptor(
  name='DataOnPremTokenResponse',
  full_name='com.rookout.DataOnPremTokenResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='com.rookout.DataOnPremTokenResponse.token', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2791,
  serialized_end=2831,
)


_AGENTSLIST = _descriptor.Descriptor(
  name='AgentsList',
  full_name='com.rookout.AgentsList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='agents_ids', full_name='com.rookout.AgentsList.agents_ids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2833,
  serialized_end=2865,
)


_ASSERTAGENTS = _descriptor.Descriptor(
  name='AssertAgents',
  full_name='com.rookout.AssertAgents',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='agent_ids', full_name='com.rookout.AssertAgents.agent_ids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2867,
  serialized_end=2900,
)


_INVALIDATEAGENTSCOMMAND = _descriptor.Descriptor(
  name='InvalidateAgentsCommand',
  full_name='com.rookout.InvalidateAgentsCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='agents_ids', full_name='com.rookout.InvalidateAgentsCommand.agents_ids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2902,
  serialized_end=2947,
)


_CONFIRMAGENTSCOMMAND = _descriptor.Descriptor(
  name='ConfirmAgentsCommand',
  full_name='com.rookout.ConfirmAgentsCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='agents_ids', full_name='com.rookout.ConfirmAgentsCommand.agents_ids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2949,
  serialized_end=2991,
)


_AGENTIDHITCOUNTPAIR = _descriptor.Descriptor(
  name='AgentIdHitCountPair',
  full_name='com.rookout.AgentIdHitCountPair',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='agent_id', full_name='com.rookout.AgentIdHitCountPair.agent_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hit_count', full_name='com.rookout.AgentIdHitCountPair.hit_count', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2993,
  serialized_end=3051,
)


_HITCOUNTUPDATEMESSAGE = _descriptor.Descriptor(
  name='HitCountUpdateMessage',
  full_name='com.rookout.HitCountUpdateMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='aug_id', full_name='com.rookout.HitCountUpdateMessage.aug_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hitCountInformation', full_name='com.rookout.HitCountUpdateMessage.hitCountInformation', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3053,
  serialized_end=3155,
)


_C2CRPCREQUEST = _descriptor.Descriptor(
  name='C2cRpcRequest',
  full_name='com.rookout.C2cRpcRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request_uuid', full_name='com.rookout.C2cRpcRequest.request_uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='com.rookout.C2cRpcRequest.message', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3157,
  serialized_end=3233,
)


_C2CRPCRESPONSE = _descriptor.Descriptor(
  name='C2cRpcResponse',
  full_name='com.rookout.C2cRpcResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request_uuid', full_name='com.rookout.C2cRpcResponse.request_uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='com.rookout.C2cRpcResponse.message', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='com.rookout.C2cRpcResponse.error', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3235,
  serialized_end=3327,
)


_STARTDATASTORECONNECTIVITYTESTCOMMAND = _descriptor.Descriptor(
  name='StartDatastoreConnectivityTestCommand',
  full_name='com.rookout.StartDatastoreConnectivityTestCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='orgId', full_name='com.rookout.StartDatastoreConnectivityTestCommand.orgId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='controllerId', full_name='com.rookout.StartDatastoreConnectivityTestCommand.controllerId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='datastoreUrl', full_name='com.rookout.StartDatastoreConnectivityTestCommand.datastoreUrl', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='workspaceId', full_name='com.rookout.StartDatastoreConnectivityTestCommand.workspaceId', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3329,
  serialized_end=3448,
)


_DATASTORECONNECTIVITYTESTC2CRESPONSE = _descriptor.Descriptor(
  name='DatastoreConnectivityTestC2cResponse',
  full_name='com.rookout.DatastoreConnectivityTestC2cResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='controllerId', full_name='com.rookout.DatastoreConnectivityTestC2cResponse.controllerId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='TestMessageId', full_name='com.rookout.DatastoreConnectivityTestC2cResponse.TestMessageId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isSuccess', full_name='com.rookout.DatastoreConnectivityTestC2cResponse.isSuccess', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='errorString', full_name='com.rookout.DatastoreConnectivityTestC2cResponse.errorString', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3450,
  serialized_end=3573,
)


_PINGDATASTORECOMMAND = _descriptor.Descriptor(
  name='PingDatastoreCommand',
  full_name='com.rookout.PingDatastoreCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='datastoreUrl', full_name='com.rookout.PingDatastoreCommand.datastoreUrl', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3575,
  serialized_end=3619,
)


_DATASTOREINFORMATION = _descriptor.Descriptor(
  name='DatastoreInformation',
  full_name='com.rookout.DatastoreInformation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='com.rookout.DatastoreInformation.version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hostname', full_name='com.rookout.DatastoreInformation.hostname', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='machine_type', full_name='com.rookout.DatastoreInformation.machine_type', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='network', full_name='com.rookout.DatastoreInformation.network', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ip', full_name='com.rookout.DatastoreInformation.ip', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='os', full_name='com.rookout.DatastoreInformation.os', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='os_release', full_name='com.rookout.DatastoreInformation.os_release', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='os_version', full_name='com.rookout.DatastoreInformation.os_version', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='os_string', full_name='com.rookout.DatastoreInformation.os_string', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3622,
  serialized_end=3801,
)

_NEWAGENTMESSAGE.fields_by_name['agent_info'].message_type = agent__info__pb2._AGENTINFORMATION
_STACKTRACE.fields_by_name['frames'].message_type = _STACKFRAME
_EXCEPTION.fields_by_name['instance'].message_type = variant__pb2._VARIANT
_EXCEPTION.fields_by_name['traceback'].message_type = _STACKTRACE
_LOGMESSAGE.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LOGMESSAGE.fields_by_name['level'].enum_type = _LOGMESSAGE_LOGLEVEL
_LOGMESSAGE.fields_by_name['arguments'].message_type = variant__pb2._VARIANT
_LOGMESSAGE.fields_by_name['exception'].message_type = _EXCEPTION
_LOGMESSAGE.fields_by_name['legacy_arguments'].message_type = variant__pb2._VARIANT
_LOGMESSAGE_LOGLEVEL.containing_type = _LOGMESSAGE
_CONTROLLERLOGMESSAGE_ERROR.containing_type = _CONTROLLERLOGMESSAGE
_CONTROLLERLOGMESSAGE_METADATAENTRY.containing_type = _CONTROLLERLOGMESSAGE
_CONTROLLERLOGMESSAGE_METADATAJSONVALUESENTRY.containing_type = _CONTROLLERLOGMESSAGE
_CONTROLLERLOGMESSAGE.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CONTROLLERLOGMESSAGE.fields_by_name['level'].enum_type = _CONTROLLERLOGMESSAGE_LOGLEVEL
_CONTROLLERLOGMESSAGE.fields_by_name['error'].message_type = _CONTROLLERLOGMESSAGE_ERROR
_CONTROLLERLOGMESSAGE.fields_by_name['metadata'].message_type = _CONTROLLERLOGMESSAGE_METADATAENTRY
_CONTROLLERLOGMESSAGE.fields_by_name['metadataJSONValues'].message_type = _CONTROLLERLOGMESSAGE_METADATAJSONVALUESENTRY
_CONTROLLERLOGMESSAGE_LOGLEVEL.containing_type = _CONTROLLERLOGMESSAGE
_RULESTATUSMESSAGE.fields_by_name['error'].message_type = variant__pb2._ERROR
_AUGREPORTMESSAGE_STRINGSCACHEENTRY.containing_type = _AUGREPORTMESSAGE
_AUGREPORTMESSAGE.fields_by_name['arguments'].message_type = variant__pb2._VARIANT
_AUGREPORTMESSAGE.fields_by_name['strings_cache'].message_type = _AUGREPORTMESSAGE_STRINGSCACHEENTRY
_AUGREPORTMESSAGE.fields_by_name['arguments2'].message_type = variant2__pb2._VARIANT2
_USERMSG.fields_by_name['aug_report'].message_type = _AUGREPORTMESSAGE
_INITIALAUGSCOMMAND_SDKCONFIGURATIONENTRY.containing_type = _INITIALAUGSCOMMAND
_INITIALAUGSCOMMAND.fields_by_name['sdk_configuration'].message_type = _INITIALAUGSCOMMAND_SDKCONFIGURATIONENTRY
_C2CINITMESSAGE.fields_by_name['controllerInfo'].message_type = controller__info__pb2._CONTROLLERINFORMATION
_DATAONPREMTOKENREQUEST.fields_by_name['access_type'].enum_type = _DATAONPREMTOKENACCESSTYPE
_HITCOUNTUPDATEMESSAGE.fields_by_name['hitCountInformation'].message_type = _AGENTIDHITCOUNTPAIR
_C2CRPCREQUEST.fields_by_name['message'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_C2CRPCRESPONSE.fields_by_name['message'].message_type = google_dot_protobuf_dot_any__pb2._ANY
DESCRIPTOR.message_types_by_name['NewAgentMessage'] = _NEWAGENTMESSAGE
DESCRIPTOR.message_types_by_name['StackFrame'] = _STACKFRAME
DESCRIPTOR.message_types_by_name['StackTrace'] = _STACKTRACE
DESCRIPTOR.message_types_by_name['Exception'] = _EXCEPTION
DESCRIPTOR.message_types_by_name['LogMessage'] = _LOGMESSAGE
DESCRIPTOR.message_types_by_name['ControllerLogMessage'] = _CONTROLLERLOGMESSAGE
DESCRIPTOR.message_types_by_name['RuleStatusMessage'] = _RULESTATUSMESSAGE
DESCRIPTOR.message_types_by_name['AugReportMessage'] = _AUGREPORTMESSAGE
DESCRIPTOR.message_types_by_name['UserMsg'] = _USERMSG
DESCRIPTOR.message_types_by_name['AddAugCommand'] = _ADDAUGCOMMAND
DESCRIPTOR.message_types_by_name['InitialAugsCommand'] = _INITIALAUGSCOMMAND
DESCRIPTOR.message_types_by_name['RemoveAugCommand'] = _REMOVEAUGCOMMAND
DESCRIPTOR.message_types_by_name['InitFinishedMessage'] = _INITFINISHEDMESSAGE
DESCRIPTOR.message_types_by_name['ClearAugsCommand'] = _CLEARAUGSCOMMAND
DESCRIPTOR.message_types_by_name['PingMessage'] = _PINGMESSAGE
DESCRIPTOR.message_types_by_name['ErrorMessage'] = _ERRORMESSAGE
DESCRIPTOR.message_types_by_name['C2CInitMessage'] = _C2CINITMESSAGE
DESCRIPTOR.message_types_by_name['DataOnPremTokenRequest'] = _DATAONPREMTOKENREQUEST
DESCRIPTOR.message_types_by_name['DataOnPremTokenResponse'] = _DATAONPREMTOKENRESPONSE
DESCRIPTOR.message_types_by_name['AgentsList'] = _AGENTSLIST
DESCRIPTOR.message_types_by_name['AssertAgents'] = _ASSERTAGENTS
DESCRIPTOR.message_types_by_name['InvalidateAgentsCommand'] = _INVALIDATEAGENTSCOMMAND
DESCRIPTOR.message_types_by_name['ConfirmAgentsCommand'] = _CONFIRMAGENTSCOMMAND
DESCRIPTOR.message_types_by_name['AgentIdHitCountPair'] = _AGENTIDHITCOUNTPAIR
DESCRIPTOR.message_types_by_name['HitCountUpdateMessage'] = _HITCOUNTUPDATEMESSAGE
DESCRIPTOR.message_types_by_name['C2cRpcRequest'] = _C2CRPCREQUEST
DESCRIPTOR.message_types_by_name['C2cRpcResponse'] = _C2CRPCRESPONSE
DESCRIPTOR.message_types_by_name['StartDatastoreConnectivityTestCommand'] = _STARTDATASTORECONNECTIVITYTESTCOMMAND
DESCRIPTOR.message_types_by_name['DatastoreConnectivityTestC2cResponse'] = _DATASTORECONNECTIVITYTESTC2CRESPONSE
DESCRIPTOR.message_types_by_name['PingDatastoreCommand'] = _PINGDATASTORECOMMAND
DESCRIPTOR.message_types_by_name['DatastoreInformation'] = _DATASTOREINFORMATION
DESCRIPTOR.enum_types_by_name['DataOnPremTokenAccessType'] = _DATAONPREMTOKENACCESSTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

NewAgentMessage = _reflection.GeneratedProtocolMessageType('NewAgentMessage', (_message.Message,), {
  'DESCRIPTOR' : _NEWAGENTMESSAGE,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.NewAgentMessage)
  })
_sym_db.RegisterMessage(NewAgentMessage)

StackFrame = _reflection.GeneratedProtocolMessageType('StackFrame', (_message.Message,), {
  'DESCRIPTOR' : _STACKFRAME,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.StackFrame)
  })
_sym_db.RegisterMessage(StackFrame)

StackTrace = _reflection.GeneratedProtocolMessageType('StackTrace', (_message.Message,), {
  'DESCRIPTOR' : _STACKTRACE,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.StackTrace)
  })
_sym_db.RegisterMessage(StackTrace)

Exception = _reflection.GeneratedProtocolMessageType('Exception', (_message.Message,), {
  'DESCRIPTOR' : _EXCEPTION,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.Exception)
  })
_sym_db.RegisterMessage(Exception)

LogMessage = _reflection.GeneratedProtocolMessageType('LogMessage', (_message.Message,), {
  'DESCRIPTOR' : _LOGMESSAGE,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.LogMessage)
  })
_sym_db.RegisterMessage(LogMessage)

ControllerLogMessage = _reflection.GeneratedProtocolMessageType('ControllerLogMessage', (_message.Message,), {

  'Error' : _reflection.GeneratedProtocolMessageType('Error', (_message.Message,), {
    'DESCRIPTOR' : _CONTROLLERLOGMESSAGE_ERROR,
    '__module__' : 'messages_pb2'
    # @@protoc_insertion_point(class_scope:com.rookout.ControllerLogMessage.Error)
    })
  ,

  'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
    'DESCRIPTOR' : _CONTROLLERLOGMESSAGE_METADATAENTRY,
    '__module__' : 'messages_pb2'
    # @@protoc_insertion_point(class_scope:com.rookout.ControllerLogMessage.MetadataEntry)
    })
  ,

  'MetadataJSONValuesEntry' : _reflection.GeneratedProtocolMessageType('MetadataJSONValuesEntry', (_message.Message,), {
    'DESCRIPTOR' : _CONTROLLERLOGMESSAGE_METADATAJSONVALUESENTRY,
    '__module__' : 'messages_pb2'
    # @@protoc_insertion_point(class_scope:com.rookout.ControllerLogMessage.MetadataJSONValuesEntry)
    })
  ,
  'DESCRIPTOR' : _CONTROLLERLOGMESSAGE,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.ControllerLogMessage)
  })
_sym_db.RegisterMessage(ControllerLogMessage)
_sym_db.RegisterMessage(ControllerLogMessage.Error)
_sym_db.RegisterMessage(ControllerLogMessage.MetadataEntry)
_sym_db.RegisterMessage(ControllerLogMessage.MetadataJSONValuesEntry)

RuleStatusMessage = _reflection.GeneratedProtocolMessageType('RuleStatusMessage', (_message.Message,), {
  'DESCRIPTOR' : _RULESTATUSMESSAGE,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.RuleStatusMessage)
  })
_sym_db.RegisterMessage(RuleStatusMessage)

AugReportMessage = _reflection.GeneratedProtocolMessageType('AugReportMessage', (_message.Message,), {

  'StringsCacheEntry' : _reflection.GeneratedProtocolMessageType('StringsCacheEntry', (_message.Message,), {
    'DESCRIPTOR' : _AUGREPORTMESSAGE_STRINGSCACHEENTRY,
    '__module__' : 'messages_pb2'
    # @@protoc_insertion_point(class_scope:com.rookout.AugReportMessage.StringsCacheEntry)
    })
  ,
  'DESCRIPTOR' : _AUGREPORTMESSAGE,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.AugReportMessage)
  })
_sym_db.RegisterMessage(AugReportMessage)
_sym_db.RegisterMessage(AugReportMessage.StringsCacheEntry)

UserMsg = _reflection.GeneratedProtocolMessageType('UserMsg', (_message.Message,), {
  'DESCRIPTOR' : _USERMSG,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.UserMsg)
  })
_sym_db.RegisterMessage(UserMsg)

AddAugCommand = _reflection.GeneratedProtocolMessageType('AddAugCommand', (_message.Message,), {
  'DESCRIPTOR' : _ADDAUGCOMMAND,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.AddAugCommand)
  })
_sym_db.RegisterMessage(AddAugCommand)

InitialAugsCommand = _reflection.GeneratedProtocolMessageType('InitialAugsCommand', (_message.Message,), {

  'SdkConfigurationEntry' : _reflection.GeneratedProtocolMessageType('SdkConfigurationEntry', (_message.Message,), {
    'DESCRIPTOR' : _INITIALAUGSCOMMAND_SDKCONFIGURATIONENTRY,
    '__module__' : 'messages_pb2'
    # @@protoc_insertion_point(class_scope:com.rookout.InitialAugsCommand.SdkConfigurationEntry)
    })
  ,
  'DESCRIPTOR' : _INITIALAUGSCOMMAND,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.InitialAugsCommand)
  })
_sym_db.RegisterMessage(InitialAugsCommand)
_sym_db.RegisterMessage(InitialAugsCommand.SdkConfigurationEntry)

RemoveAugCommand = _reflection.GeneratedProtocolMessageType('RemoveAugCommand', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEAUGCOMMAND,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.RemoveAugCommand)
  })
_sym_db.RegisterMessage(RemoveAugCommand)

InitFinishedMessage = _reflection.GeneratedProtocolMessageType('InitFinishedMessage', (_message.Message,), {
  'DESCRIPTOR' : _INITFINISHEDMESSAGE,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.InitFinishedMessage)
  })
_sym_db.RegisterMessage(InitFinishedMessage)

ClearAugsCommand = _reflection.GeneratedProtocolMessageType('ClearAugsCommand', (_message.Message,), {
  'DESCRIPTOR' : _CLEARAUGSCOMMAND,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.ClearAugsCommand)
  })
_sym_db.RegisterMessage(ClearAugsCommand)

PingMessage = _reflection.GeneratedProtocolMessageType('PingMessage', (_message.Message,), {
  'DESCRIPTOR' : _PINGMESSAGE,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.PingMessage)
  })
_sym_db.RegisterMessage(PingMessage)

ErrorMessage = _reflection.GeneratedProtocolMessageType('ErrorMessage', (_message.Message,), {
  'DESCRIPTOR' : _ERRORMESSAGE,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.ErrorMessage)
  })
_sym_db.RegisterMessage(ErrorMessage)

C2CInitMessage = _reflection.GeneratedProtocolMessageType('C2CInitMessage', (_message.Message,), {
  'DESCRIPTOR' : _C2CINITMESSAGE,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.C2CInitMessage)
  })
_sym_db.RegisterMessage(C2CInitMessage)

DataOnPremTokenRequest = _reflection.GeneratedProtocolMessageType('DataOnPremTokenRequest', (_message.Message,), {
  'DESCRIPTOR' : _DATAONPREMTOKENREQUEST,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.DataOnPremTokenRequest)
  })
_sym_db.RegisterMessage(DataOnPremTokenRequest)

DataOnPremTokenResponse = _reflection.GeneratedProtocolMessageType('DataOnPremTokenResponse', (_message.Message,), {
  'DESCRIPTOR' : _DATAONPREMTOKENRESPONSE,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.DataOnPremTokenResponse)
  })
_sym_db.RegisterMessage(DataOnPremTokenResponse)

AgentsList = _reflection.GeneratedProtocolMessageType('AgentsList', (_message.Message,), {
  'DESCRIPTOR' : _AGENTSLIST,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.AgentsList)
  })
_sym_db.RegisterMessage(AgentsList)

AssertAgents = _reflection.GeneratedProtocolMessageType('AssertAgents', (_message.Message,), {
  'DESCRIPTOR' : _ASSERTAGENTS,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.AssertAgents)
  })
_sym_db.RegisterMessage(AssertAgents)

InvalidateAgentsCommand = _reflection.GeneratedProtocolMessageType('InvalidateAgentsCommand', (_message.Message,), {
  'DESCRIPTOR' : _INVALIDATEAGENTSCOMMAND,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.InvalidateAgentsCommand)
  })
_sym_db.RegisterMessage(InvalidateAgentsCommand)

ConfirmAgentsCommand = _reflection.GeneratedProtocolMessageType('ConfirmAgentsCommand', (_message.Message,), {
  'DESCRIPTOR' : _CONFIRMAGENTSCOMMAND,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.ConfirmAgentsCommand)
  })
_sym_db.RegisterMessage(ConfirmAgentsCommand)

AgentIdHitCountPair = _reflection.GeneratedProtocolMessageType('AgentIdHitCountPair', (_message.Message,), {
  'DESCRIPTOR' : _AGENTIDHITCOUNTPAIR,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.AgentIdHitCountPair)
  })
_sym_db.RegisterMessage(AgentIdHitCountPair)

HitCountUpdateMessage = _reflection.GeneratedProtocolMessageType('HitCountUpdateMessage', (_message.Message,), {
  'DESCRIPTOR' : _HITCOUNTUPDATEMESSAGE,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.HitCountUpdateMessage)
  })
_sym_db.RegisterMessage(HitCountUpdateMessage)

C2cRpcRequest = _reflection.GeneratedProtocolMessageType('C2cRpcRequest', (_message.Message,), {
  'DESCRIPTOR' : _C2CRPCREQUEST,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.C2cRpcRequest)
  })
_sym_db.RegisterMessage(C2cRpcRequest)

C2cRpcResponse = _reflection.GeneratedProtocolMessageType('C2cRpcResponse', (_message.Message,), {
  'DESCRIPTOR' : _C2CRPCRESPONSE,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.C2cRpcResponse)
  })
_sym_db.RegisterMessage(C2cRpcResponse)

StartDatastoreConnectivityTestCommand = _reflection.GeneratedProtocolMessageType('StartDatastoreConnectivityTestCommand', (_message.Message,), {
  'DESCRIPTOR' : _STARTDATASTORECONNECTIVITYTESTCOMMAND,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.StartDatastoreConnectivityTestCommand)
  })
_sym_db.RegisterMessage(StartDatastoreConnectivityTestCommand)

DatastoreConnectivityTestC2cResponse = _reflection.GeneratedProtocolMessageType('DatastoreConnectivityTestC2cResponse', (_message.Message,), {
  'DESCRIPTOR' : _DATASTORECONNECTIVITYTESTC2CRESPONSE,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.DatastoreConnectivityTestC2cResponse)
  })
_sym_db.RegisterMessage(DatastoreConnectivityTestC2cResponse)

PingDatastoreCommand = _reflection.GeneratedProtocolMessageType('PingDatastoreCommand', (_message.Message,), {
  'DESCRIPTOR' : _PINGDATASTORECOMMAND,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.PingDatastoreCommand)
  })
_sym_db.RegisterMessage(PingDatastoreCommand)

DatastoreInformation = _reflection.GeneratedProtocolMessageType('DatastoreInformation', (_message.Message,), {
  'DESCRIPTOR' : _DATASTOREINFORMATION,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.DatastoreInformation)
  })
_sym_db.RegisterMessage(DatastoreInformation)


DESCRIPTOR._options = None
_LOGMESSAGE.fields_by_name['formatted_message']._options = None
_LOGMESSAGE.fields_by_name['legacy_arguments']._options = None
_CONTROLLERLOGMESSAGE_METADATAENTRY._options = None
_CONTROLLERLOGMESSAGE_METADATAJSONVALUESENTRY._options = None
_AUGREPORTMESSAGE_STRINGSCACHEENTRY._options = None
_INITIALAUGSCOMMAND_SDKCONFIGURATIONENTRY._options = None
# @@protoc_insertion_point(module_scope)



import six
import os
import inspect

from rook.exceptions import RookHashFailedException, RookHashCalculationFailed, \
    RookSourceFileNotFound

from rook.processor.error import Error

from rook.logger import logger


class FileUtils(object):
    def __init__(self):
        # This is to allow tests to reliably hook the file open function
        self.open_file = open

    def get_safe_file_contents(self, module):
        filepath = inspect.getsourcefile(module)
        try:
            return self.get_file_contents(None, module, filepath)
        except Exception:
            logger.exception("Error while reading file")
            return None

    def get_file_contents(self, location, module, filepath):
        if not filepath:
            if module.__file__.endswith('.pyc'):
                if location:
                    location.send_warning(Error(exc=RookSourceFileNotFound(module.__file__)))
                return None
            raise RookHashFailedException(module.__name__)

        try:
            with self.open_file(filepath, 'rb') as f:
                string = f.read()
        except IOError as exc:
            # if reading the file has failed, it might be because it's a zipimport.
            # try loading the file contents using the module's loader.
            if not os.path.exists(filepath) and ".zip/" in filepath:
                relative_path = filepath.split(".zip/", 2)[1]
                string = module.__loader__.get_data(relative_path)
            else:
                if not os.path.isfile(filepath):
                    if location:
                        location.send_warning(Error(exc=RookSourceFileNotFound(module.__file__)))
                    return None
                raise RookHashCalculationFailed(filepath, module.__name__, exc)

        return self._normalize_file_contents(string)

    @staticmethod
    def _normalize_file_contents(data):
        if six.PY2:
            string = data.replace('\r\n', '\n').replace('\r\x00\n\x00', '\n\x00').replace('\r', '\n')
        else:
            string = data.decode().replace('\r\n', '\n').replace('\r\x00\n\x00', '\n\x00'). \
                replace('\r', '\n').encode('UTF8')
        return string



from .namespace import Namespace
from .collection_namespace import ListNamespace
from .traceback_namespace import TracebackNamespace


class StackNamespace(Namespace):
    DEFAULT_TRACEBACK_DEPTH = 1000
    DEFAULT_FRAMES_DEPTH = 100

    def __init__(self, frame):
        super(StackNamespace, self).__init__(self.METHODS)
        self._frame = frame

    def read_attribute(self, name):
        raise NotImplementedError("StackNamespace does not support attribute read!")

    def read_key(self, key):
        pos = int(key)

        current_frame = self._frame

        for i in range(pos):
            current_frame = current_frame.f_back()

        return current_frame

    def traceback(self, args=None):
        if args:
            depth = int(args)
        else:
            depth = self.DEFAULT_TRACEBACK_DEPTH

        return TracebackNamespace(self._frame, depth)

    def frames(self, args=None):
        if args:
            depth = int(args)
        else:
            depth = self.DEFAULT_FRAMES_DEPTH

        result = []

        current_frame = self._frame

        for i in range(depth):
            result.append(current_frame.dump(None))

            current_frame = current_frame.f_back()

            if not current_frame:
                break

        return ListNamespace(result)

    METHODS = (traceback, frames)



from abc import ABCMeta, abstractmethod

import rook.protobuf.envelope_pb2 as envelope_pb


class IEnvelopeWrapper:
    __metaclass__ = ABCMeta

    @abstractmethod
    def get_buffer(self):
        pass

    @abstractmethod
    def __len__(self):
        pass

    @staticmethod
    def get_serialized_envelope(message):
        envelope = envelope_pb.Envelope()
        envelope.timestamp.GetCurrentTime()
        envelope.msg.Pack(message)

        return envelope.SerializeToString()


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: agent_info.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10\x61gent_info.proto\x12\x0b\x63om.rookout\"\xa6\x01\n\x0eSCMInformation\x12\x0e\n\x06\x63ommit\x18\x01 \x01(\t\x12\x0e\n\x06origin\x18\x02 \x01(\t\x12\x37\n\x07sources\x18\x04 \x03(\x0b\x32&.com.rookout.SCMInformation.SourceInfo\x1a\x35\n\nSourceInfo\x12\x17\n\x0fremoteOriginUrl\x18\x01 \x01(\t\x12\x0e\n\x06\x63ommit\x18\x02 \x01(\tJ\x04\x08\x03\x10\x04\"K\n\x12NetworkInformation\x12\x0f\n\x07ip_addr\x18\x01 \x01(\t\x12\x0f\n\x07network\x18\x02 \x01(\t\x12\x13\n\x0b\x65xternal_ip\x18\x03 \x01(\t\"c\n\x11SystemInformation\x12\x10\n\x08hostname\x18\x01 \x01(\t\x12\n\n\x02os\x18\x02 \x01(\t\x12\x12\n\nos_version\x18\x03 \x01(\t\x12\x0e\n\x06\x64istro\x18\x04 \x01(\t\x12\x0c\n\x04\x61rch\x18\x05 \x01(\t\"5\n\x12VersionInformation\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x0e\n\x06\x63ommit\x18\x02 \x01(\t\"I\n\x13PlatformInformation\x12\x10\n\x08platform\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x0f\n\x07variant\x18\x03 \x01(\t\"\xd1\x03\n\x10\x41gentInformation\x12\x10\n\x08\x61gent_id\x18\x01 \x01(\t\x12\x30\n\x07version\x18\x02 \x01(\x0b\x32\x1f.com.rookout.VersionInformation\x12\x30\n\x07network\x18\x03 \x01(\x0b\x32\x1f.com.rookout.NetworkInformation\x12.\n\x06system\x18\x04 \x01(\x0b\x32\x1e.com.rookout.SystemInformation\x12\x32\n\x08platform\x18\x05 \x01(\x0b\x32 .com.rookout.PlatformInformation\x12\x12\n\nexecutable\x18\x06 \x01(\t\x12\x19\n\x11\x63ommand_arguments\x18\x07 \x03(\t\x12\x12\n\nprocess_id\x18\x08 \x01(\r\x12\x39\n\x06labels\x18\t \x03(\x0b\x32).com.rookout.AgentInformation.LabelsEntry\x12(\n\x03scm\x18\n \x01(\x0b\x32\x1b.com.rookout.SCMInformation\x12\x0c\n\x04tags\x18\x0b \x03(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"F\n\x15\x41gentInformationArray\x12-\n\x06\x61gents\x18\x01 \x03(\x0b\x32\x1d.com.rookout.AgentInformationBO\n\x19\x63om.rookout.rook.protobufZ2github.com/Rookout/management/pkg/protos/protobuf2b\x06proto3')



_SCMINFORMATION = DESCRIPTOR.message_types_by_name['SCMInformation']
_SCMINFORMATION_SOURCEINFO = _SCMINFORMATION.nested_types_by_name['SourceInfo']
_NETWORKINFORMATION = DESCRIPTOR.message_types_by_name['NetworkInformation']
_SYSTEMINFORMATION = DESCRIPTOR.message_types_by_name['SystemInformation']
_VERSIONINFORMATION = DESCRIPTOR.message_types_by_name['VersionInformation']
_PLATFORMINFORMATION = DESCRIPTOR.message_types_by_name['PlatformInformation']
_AGENTINFORMATION = DESCRIPTOR.message_types_by_name['AgentInformation']
_AGENTINFORMATION_LABELSENTRY = _AGENTINFORMATION.nested_types_by_name['LabelsEntry']
_AGENTINFORMATIONARRAY = DESCRIPTOR.message_types_by_name['AgentInformationArray']
SCMInformation = _reflection.GeneratedProtocolMessageType('SCMInformation', (_message.Message,), {

  'SourceInfo' : _reflection.GeneratedProtocolMessageType('SourceInfo', (_message.Message,), {
    'DESCRIPTOR' : _SCMINFORMATION_SOURCEINFO,
    '__module__' : 'agent_info_pb2'
    # @@protoc_insertion_point(class_scope:com.rookout.SCMInformation.SourceInfo)
    })
  ,
  'DESCRIPTOR' : _SCMINFORMATION,
  '__module__' : 'agent_info_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.SCMInformation)
  })
_sym_db.RegisterMessage(SCMInformation)
_sym_db.RegisterMessage(SCMInformation.SourceInfo)

NetworkInformation = _reflection.GeneratedProtocolMessageType('NetworkInformation', (_message.Message,), {
  'DESCRIPTOR' : _NETWORKINFORMATION,
  '__module__' : 'agent_info_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.NetworkInformation)
  })
_sym_db.RegisterMessage(NetworkInformation)

SystemInformation = _reflection.GeneratedProtocolMessageType('SystemInformation', (_message.Message,), {
  'DESCRIPTOR' : _SYSTEMINFORMATION,
  '__module__' : 'agent_info_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.SystemInformation)
  })
_sym_db.RegisterMessage(SystemInformation)

VersionInformation = _reflection.GeneratedProtocolMessageType('VersionInformation', (_message.Message,), {
  'DESCRIPTOR' : _VERSIONINFORMATION,
  '__module__' : 'agent_info_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.VersionInformation)
  })
_sym_db.RegisterMessage(VersionInformation)

PlatformInformation = _reflection.GeneratedProtocolMessageType('PlatformInformation', (_message.Message,), {
  'DESCRIPTOR' : _PLATFORMINFORMATION,
  '__module__' : 'agent_info_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.PlatformInformation)
  })
_sym_db.RegisterMessage(PlatformInformation)

AgentInformation = _reflection.GeneratedProtocolMessageType('AgentInformation', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _AGENTINFORMATION_LABELSENTRY,
    '__module__' : 'agent_info_pb2'
    # @@protoc_insertion_point(class_scope:com.rookout.AgentInformation.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _AGENTINFORMATION,
  '__module__' : 'agent_info_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.AgentInformation)
  })
_sym_db.RegisterMessage(AgentInformation)
_sym_db.RegisterMessage(AgentInformation.LabelsEntry)

AgentInformationArray = _reflection.GeneratedProtocolMessageType('AgentInformationArray', (_message.Message,), {
  'DESCRIPTOR' : _AGENTINFORMATIONARRAY,
  '__module__' : 'agent_info_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.AgentInformationArray)
  })
_sym_db.RegisterMessage(AgentInformationArray)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.rookout.rook.protobufZ2github.com/Rookout/management/pkg/protos/protobuf2'
  _AGENTINFORMATION_LABELSENTRY._options = None
  _AGENTINFORMATION_LABELSENTRY._serialized_options = b'8\001'
  _SCMINFORMATION._serialized_start=34
  _SCMINFORMATION._serialized_end=200
  _SCMINFORMATION_SOURCEINFO._serialized_start=141
  _SCMINFORMATION_SOURCEINFO._serialized_end=194
  _NETWORKINFORMATION._serialized_start=202
  _NETWORKINFORMATION._serialized_end=277
  _SYSTEMINFORMATION._serialized_start=279
  _SYSTEMINFORMATION._serialized_end=378
  _VERSIONINFORMATION._serialized_start=380
  _VERSIONINFORMATION._serialized_end=433
  _PLATFORMINFORMATION._serialized_start=435
  _PLATFORMINFORMATION._serialized_end=508
  _AGENTINFORMATION._serialized_start=511
  _AGENTINFORMATION._serialized_end=976
  _AGENTINFORMATION_LABELSENTRY._serialized_start=931
  _AGENTINFORMATION_LABELSENTRY._serialized_end=976
  _AGENTINFORMATIONARRAY._serialized_start=978
  _AGENTINFORMATIONARRAY._serialized_end=1048
# @@protoc_insertion_point(module_scope)



from six import iteritems

from ...logger import logger

from ..error import Error
from ...user_warnings import UserWarnings

from ..namespaces.python_object_namespace import PythonObjectNamespace


class Set(object):

    def __init__(self, arguments, factory):
        self._paths = list()

        for key, value in iteritems(arguments['paths']):
            try:
                dest_path = factory.get_path(key)
                source_path = factory.get_path(value)
            except Exception as exc:
                message = "Failed to load dest:source path pair"
                logger.exception(message)
                UserWarnings.send_warning(Error(exc=exc, message=message))
                continue


            self._paths.append((dest_path, source_path))

    def execute(self, namespace):
        for dest_path, source_path in self._paths:
            try:
                value = source_path.read_from(namespace)
                if isinstance(value, PythonObjectNamespace) and \
                        value.dump_config == PythonObjectNamespace.ObjectDumpConfig.default_limits(value.obj):
                    value.dump_config = PythonObjectNamespace.ObjectDumpConfig.tailor_limits(value.obj)

                dest_path.write_to(namespace, value)
            except Exception as exc:
                message = "Failed to execute dest:source path pair"
                logger.exception(message)
                UserWarnings.send_warning(Error(exc=exc, message=message))
                continue



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: variant2.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import variant_pb2 as variant__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0evariant2.proto\x12\x0b\x63om.rookout\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\rvariant.proto\"\xa0\x01\n\x06\x45rror2\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12)\n\nparameters\x18\x03 \x01(\x0b\x32\x15.com.rookout.Variant2\x12\"\n\x03\x65xc\x18\x04 \x01(\x0b\x32\x15.com.rookout.Variant2\x12(\n\ttraceback\x18\x05 \x01(\x0b\x32\x15.com.rookout.Variant2\"\xe1\x04\n\x08Variant2\x12\x1e\n\x16variant_type_max_depth\x18\x01 \x01(\r\x12$\n\x1coriginal_type_index_in_cache\x18\x02 \x01(\r\x12 \n\x18\x61ttribute_names_in_cache\x18\x03 \x03(\r\x12/\n\x10\x61ttribute_values\x18\x04 \x03(\x0b\x32\x15.com.rookout.Variant2\x12\x15\n\roriginal_size\x18\x05 \x01(\r\x12\x12\n\nlong_value\x18\x06 \x01(\x03\x12\x1c\n\x14\x62ytes_index_in_cache\x18\x07 \x01(\r\x12.\n\x0f\x63ollection_keys\x18\x08 \x03(\x0b\x32\x15.com.rookout.Variant2\x12\x30\n\x11\x63ollection_values\x18\t \x03(\x0b\x32\x15.com.rookout.Variant2\x12\x14\n\x0c\x64ouble_value\x18\n \x01(\x01\x12\x34\n\x0b\x63ode_values\x18\x0b \x03(\x0b\x32\x1f.com.rookout.Variant.CodeObject\x12.\n\ntime_value\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x0b\x65rror_value\x18\x10 \x01(\x0b\x32\x13.com.rookout.Error2\x12\x33\n\rcomplex_value\x18\x11 \x01(\x0b\x32\x1c.com.rookout.Variant.Complex\x12\x36\n\x08livetail\x18\x12 \x01(\x0b\x32$.com.rookout.Variant.LiveTailMessageBO\n\x19\x63om.rookout.rook.protobufZ2github.com/Rookout/management/pkg/protos/protobuf2b\x06proto3')



_ERROR2 = DESCRIPTOR.message_types_by_name['Error2']
_VARIANT2 = DESCRIPTOR.message_types_by_name['Variant2']
Error2 = _reflection.GeneratedProtocolMessageType('Error2', (_message.Message,), {
  'DESCRIPTOR' : _ERROR2,
  '__module__' : 'variant2_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.Error2)
  })
_sym_db.RegisterMessage(Error2)

Variant2 = _reflection.GeneratedProtocolMessageType('Variant2', (_message.Message,), {
  'DESCRIPTOR' : _VARIANT2,
  '__module__' : 'variant2_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.Variant2)
  })
_sym_db.RegisterMessage(Variant2)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.rookout.rook.protobufZ2github.com/Rookout/management/pkg/protos/protobuf2'
  _ERROR2._serialized_start=80
  _ERROR2._serialized_end=240
  _VARIANT2._serialized_start=243
  _VARIANT2._serialized_end=852
# @@protoc_insertion_point(module_scope)
